==> haskell-cereal-0.5.4.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cereal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cereal
version: 0.5.4.0
id: cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
key: cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
license: BSD3
maintainer: Trevor Elliott <trevor@galois.com>
stability: provisional
homepage: https://github.com/GaloisInc/cereal
synopsis: A binary serialization library
description:
    A binary serialization library, similar to binary, that introduces an isolate
    primitive for parser isolation, and labeled blocks for better error messages.
category: Data, Parsing
author: Lennart Kolmodin <kolmodin@dtek.chalmers.se>,
        Galois Inc.,
        Lemmih <lemmih@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Serialize Data.Serialize.Get Data.Serialize.IEEE754
    Data.Serialize.Put
abi: ed459ea038cbdb253abe2c011f65c556
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cereal-0.5.4.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/cereal-0.5.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cereal-0.5.4.0
hs-libraries: HScereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
depends:
    base-4.10.1.0 containers-0.5.10.2 array-0.5.2.0 ghc-prim-0.5.1.1
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-cereal/html/cereal.haddock
haddock-html: /usr/share/doc/haskell-cereal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cereal-0.5.5.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cereal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cereal
version: 0.5.5.0
id: cereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I
key: cereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I
license: BSD3
maintainer: Trevor Elliott <trevor@galois.com>
stability: provisional
homepage: https://github.com/GaloisInc/cereal
synopsis: A binary serialization library
description:
    A binary serialization library, similar to binary, that introduces an isolate
    primitive for parser isolation, and labeled blocks for better error messages.
category: Data, Parsing
author: Lennart Kolmodin <kolmodin@dtek.chalmers.se>,
        Galois Inc.,
        Lemmih <lemmih@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Serialize Data.Serialize.Get Data.Serialize.IEEE754
    Data.Serialize.Put
abi: 6218d13b02d73798bf7f063f3f4fa054
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cereal-0.5.5.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/cereal-0.5.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cereal-0.5.5.0
hs-libraries: HScereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I
depends:
    base-4.10.1.0 containers-0.5.10.2 array-0.5.2.0 ghc-prim-0.5.1.1
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-cereal/html/cereal.haddock
haddock-html: /usr/share/doc/haskell-cereal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
